Authorizers
===========

.. autosummary::
   :nosignatures:

   custodia.httpd.authorizers.SimplePathAuthz
   custodia.httpd.authorizers.UserNameSpace
   custodia.message.kem.KEMKeysStore

.. autoclass:: custodia.httpd.authorizers.SimplePathAuthz
    :members:
    :undoc-members:
    :show-inheritance:

.. autoclass:: custodia.httpd.authorizers.UserNameSpace
    :members:
    :undoc-members:
    :show-inheritance:

.. autoclass:: custodia.message.kem.KEMKeysStore
    :members:
    :undoc-members:
    :show-inheritance:
